@@ -22,7 +22,6 @@
 #ifndef _INTERFACE_H_
 #define _INTERFACE_H_
 
-#include <gconf/gconf-client.h>
 #include <gtk/gtk.h>
 #include <gnome.h>
 #include <bonobo/bonobo-dock-layout.h>
@@ -39,13 +38,13 @@ typedef struct _MainApp
     GObject parent_struct;
     GtkWidget *window;
     GtkWidget *entry;
-    GtkWidget *textbar;
+    GtkWidget *actionbar, *textbar;
     GtkWidget *preview_label;
     GtkWidget *fontpicker;
     GtkWidget *chartable;
+    gboolean insert_at_end;
     GList *buttons;
     GtkStyle *btnstyle;
-    GConfClient *conf;
 } MainApp;
 
 typedef struct _MainAppClass
@@ -60,8 +59,5 @@ GType main_app_get_type (void);
 MainApp *main_app_new (void);
 void main_app_destroy (MainApp *obj);
 
-gboolean check_gail(GtkWidget *widget);
-void add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc);
-void add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType type);
 
 #endif /* _INTERFACE_H_ */
