@@ -28,9 +28,6 @@
 
 #include "menus.h"
 #include "callbacks.h"
-#include "gcharmap-map-24.xpm"
-#include "gcharmap-map-16.xpm"
-
 
 GnomeUIInfo file_menu[] =
 {
@@ -50,7 +47,7 @@ GnomeUIInfo edit_menu[] =
     GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_ITEM_DATA(N_("Insert Character..."),
       N_("Insert character(s) by choosing character codes."), cb_insert_char_click,
-      NULL, gcharmap_map_16_xpm),
+			  NULL, NULL),
     GNOMEUIINFO_END
 };
 
@@ -97,7 +94,7 @@ GnomeUIInfo menubar[] =
 
 GnomeUIInfo toolbar[] = {
     GNOMEUIINFO_ITEM(N_("Insert"), N_("Insert character(s) by choosing character codes"),
-      cb_insert_char_click, &gcharmap_map_24_xpm),
+      cb_insert_char_click, NULL),
     GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_ITEM_STOCK(N_("Cut"), N_("Cut the selection"),
       cb_cut_click, GNOME_STOCK_PIXMAP_CUT),
