@@ -1,4 +1,4 @@
-/* $Id: gdict-app.c,v 1.28 2001/12/05 22:38:30 kevinv Exp $ */
+/* $Id: gdict-app.c,v 1.32 2002/01/09 02:02:32 kevinv Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -66,12 +66,12 @@ socket_dialog_close_cb (GtkWidget *widget, gpointer data)
 static void
 socket_error_cb (GtkWidget *widget, gchar *message, gpointer data) 
 {
-    if (!socket_error_dialog) {
-        socket_error_dialog = 
-            gnome_error_dialog_parented (message, GTK_WINDOW (gdict_app));
-        gtk_signal_connect (GTK_OBJECT (socket_error_dialog), "close",
-                            GTK_SIGNAL_FUNC (socket_dialog_close_cb), NULL);
-    }
+    socket_error_dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                  		  GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                  		  "%s", message, NULL); 
+    gtk_dialog_run (GTK_DIALOG (socket_error_dialog));
+    gtk_widget_destroy (socket_error_dialog);
+    
 }
 
 /* gdict_init_context
@@ -436,13 +436,6 @@ find_again_cb (GtkMenuItem *menuitem, gpointer user_data)
         gdict_defbox_find (defbox, find_text, FALSE);
 }
 
-static gint
-pref_dialog_close_cb (GtkWidget *widget, gpointer user_data) 
-{
-    pref_dialog = NULL;
-    return FALSE;
-}
-
 static void
 pref_dialog_apply_cb (GtkWidget *widget, gpointer user_data) 
 {
@@ -456,27 +449,25 @@ gdict_not_online ()
     GtkWidget *w;
     gchar *s;
     
-    s = g_strdup_printf (_("Unable to perform requested operation, either because the server\n"
-			   "you are using is down or because you are not connected to the\n"
-			   "Internet. If you are not already connected to the Internet, please\n" 
-    			   "do so and try again."));
-    w = gnome_error_dialog (s);
-    gnome_dialog_run_and_close (GNOME_DIALOG (w));
+    s = g_strdup_printf (_("Unable to perform requested operation. \n"
+    		           "Either the server you are using is not available \n"
+    		           "or you are not connected to the Internet."));
+    w = gtk_message_dialog_new (NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+                                     GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+                                     "%s", s, NULL); 
+    gtk_dialog_run (GTK_DIALOG (w));
+    gtk_widget_destroy (w);
     g_free (s);
 }
 
 void
 gdict_app_show_preferences (void) 
 {
+	
     if (!pref_dialog) {
+    g_print ("show prefs \n");
         pref_dialog = gdict_pref_dialog_new (context);
-        gtk_signal_connect (GTK_OBJECT (pref_dialog), "apply_changes",
-                            GTK_SIGNAL_FUNC (pref_dialog_apply_cb), NULL);
-        gtk_signal_connect (GTK_OBJECT (pref_dialog), "socket_error",
-                            GTK_SIGNAL_FUNC (socket_error_cb), NULL);
-        gtk_signal_connect (GTK_OBJECT (pref_dialog), "close",
-                            GTK_SIGNAL_FUNC (pref_dialog_close_cb),
-			    NULL);
+        
     }
 
     gtk_widget_show (pref_dialog);
@@ -603,7 +594,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
   
     tooltips = gtk_tooltips_new ();
   
-    gdict_app = gnome_app_new ("GDict", "GDict");
+    gdict_app = gnome_app_new ("Dictionary", "Dictionary");
     gtk_window_set_default_size (GTK_WINDOW (gdict_app), 450, 330);
     
     dock = GNOME_APP (gdict_app)->dock;
@@ -640,7 +631,7 @@ GtkWidget *gdict_app_create (gboolean applet) {
     g_signal_connect (G_OBJECT (button), "drag_data_received",
     		      G_CALLBACK (lookup_button_drag_cb), defbox);
 
-    gnome_word_entry = gnome_entry_new ("Word entry");
+    gnome_word_entry = gnome_entry_new ("Wordentry");
     gtk_widget_show (gnome_word_entry);
     /*gtk_box_pack_start (GTK_BOX (vbox), gnome_word_entry, FALSE, FALSE, 0);*/
     gtk_box_pack_start (GTK_BOX (hbox), gnome_word_entry, TRUE, TRUE, 0);
