@@ -1,7 +1,7 @@
 #ifndef __GDICT_APPLET_H_
 #define __GDICT_APPLET_H_
 
-/* $Id: gdict-applet.h,v 1.5 2001/12/05 03:30:18 kevinv Exp $ */
+/* $Id: gdict-applet.h,v 1.6 2001/12/12 21:42:39 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim@cs.cmu.edu>
@@ -12,6 +12,8 @@
  *  GDict panel applet
  *
  */
+ 
+#include <panel-applet.h>
 
 /* This structure contains the internal state of the gdict applet.
  * Everything the functions and signal handlers need to be able to
@@ -19,10 +21,14 @@
 typedef struct _GDictApplet {
 	GtkWidget *applet_widget;
 	GtkWidget *button_widget;
+	GdkPixbuf *pixbuf;
+	GtkWidget *image;
 	GtkWidget *vbox_widget;
 	GtkWidget *entry_widget;
 	GtkWidget *handlebox_widget;
+	PanelAppletOrient orient;
 	gboolean handle;
+	gint panel_size;
 } GDictApplet;
 
 
